# -------------------------------------------------------------------------
# tarpuy ------------------------------------------------------------------
# -------------------------------------------------------------------------
#> open https://flavjack.github.io/inti/
#> open https://flavjack.shinyapps.io/tarpuy/
#> author .: Flavio Lozano-Isla (lozanoisla.com)
#> date .: 2020-03-24
# -------------------------------------------------------------------------

# -------------------------------------------------------------------------
# packages ----------------------------------------------------------------
# -------------------------------------------------------------------------

suppressPackageStartupMessages({
  
library(inti)
library(bslib)
library(metathis)
library(googlesheets4)
library(googleAuthR)
library(shinydashboard)
library(tidyverse)
library(stringi)

})
